Learn R Programming

vvmover (version 1.6.0)

get_recent_file_date_filename_ymd: Get recent file date filename ymd

Description

This function determines the path of the most recent version of a file in a folder. Sorting is determined by file name where it is a condition that the filename starts with ymd encoding.

Usage

get_recent_file_date_filename_ymd(path, match)

Value

The most recent file

Arguments

path

The path to search for the file.

match

The search term to match in the file name.

See Also

Other Get recent files: get_recent_file_date_modified(), get_recent_file()