Learn R Programming

vvmover (version 1.6.0)

save_session_info_to_file: Save session info to a file

Description

Stores session info in a .txt file.

Usage

save_session_info_to_file(path)

Value

A .txt file containing session info, saved at the specified path.

Arguments

path

The directory path where the session info file will be saved.