unzip_read_delim: Extract a .zip archive and read in with read_delim
Description
Extract a .zip archive and read it in with readr's read_delim function. The file is extracted to a temporary location, and then deleted after reading it.
Usage
unzip_read_delim(zip_path, filename = NULL, ...)
Value
Dataframe
Arguments
zip_path
The file path of the .zip archive
filename
OPTIONAL: The file name of the file in the .zip archive to be read. This parameter can be left empty if there is only 1 file in the archive.
...
arguments to the readr::read_delim function. see: read_delim